const db = require('../../shared/db');

async function getProductsByUrls(urls) {
    const query = 'SELECT * FROM products WHERE url IN (?)';
    const [products] = await db.query(query, [urls]);
    return products;
}

async function createProducts(products) {
    const query = 'INSERT INTO products (url) VALUES ?';
    const values = products.map(product => [product.url]);
    const [result] = await db.query(query, [values]);
    return products.map((product, index) => ({id: result.insertId + index, ...product}));
}

async function getProductById(productId) {
    const query = 'SELECT * FROM products WHERE id = ?';
    const [rows] = await db.query(query, [productId]);
    return rows.length > 0 ? rows[0] : null;
}

module.exports = {
    getProductsByUrls,
    createProducts,
    getProductById,
};